@@ -52,10 +52,13 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
+
 #include "dialog.h"
 #include "error.h"
 #include "help.h"
 #include "base.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -68,97 +71,116 @@
 /*------------------------------------------------------------------*/
 static int return_d_close(void)
 {
- return (D_CLOSE);
+  return (D_CLOSE);
 }
 
 /*------------------------------------------------------------------*/
 static int standard_error (char *str)
 {
-   DIALOG d[3];
+  DIALOG d[3];
 
-   color_one_dialog (d);
-   d[0].proc=my_textbox_proc;
-   d[0].d2=0;
-   d[0].dp=str;
-   d[0].key=0;
-   d[0].flags=0;
-   d[0].x=MENU_VIRTUAL_W/4;
-   d[0].y=(3*MENU_VIRTUAL_H)/8;
-   d[0].w=(MENU_VIRTUAL_W)/2;
-   d[0].h=(MENU_VIRTUAL_H)/4;
-   menu_real_coord (d);
+  memset(d,0,sizeof(d));
 
-   d[1].proc=d_keyboard_proc;
-   d[1].dp=return_d_close;
-   d[1].key=' ';
-   d[1].d1=KEY_ENTER;
-   d[1].d2=KEY_ESC;
+  color_one_dialog (d);
+  d[0].proc=my_textbox_proc;
+  d[0].d2=0;
+  d[0].dp=str;
+  d[0].key=0;
+  d[0].flags=0;
+  d[0].x=MENU_VIRTUAL_W/4;
+  d[0].y=(3*MENU_VIRTUAL_H)/8;
+  d[0].w=(MENU_VIRTUAL_W)/2;
+  d[0].h=(MENU_VIRTUAL_H)/4;
+  menu_real_coord (d);
 
-   d[2].proc=NULL;
+  d[1].proc=d_keyboard_proc;
+  d[1].dp=return_d_close;
+  d[1].key=' ';
+  d[1].d1=KEY_ENTER;
+  d[1].d2=KEY_ESC;
 
-   my_do_dialog(d,0);
+  d[2].proc=NULL;
+
+  my_do_dialog(d,0);
  
-   return 0;
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
 int error_not_enough_teams (void)
 {
- return (standard_error("Not enough teams.\nYou must select at least 2 teams from the \"Teams\" menu."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_NOTENOUGHTEAMS)));
 }
 
 /*------------------------------------------------------------------*/
 int error_not_enough_big_data (void)
 {
- return (standard_error("Not enough memory to expand level.\nChoose a smaller level or see the \".htm\" doc and try command line options such as \"-mem n\"."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_NOTENOUGHBIGDATA)));
 }
 
 /*------------------------------------------------------------------*/
 int error_graphics_init_failed (void)
 {
- return (standard_error("Unable to start graphic mode"));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_GRAPHICSINITFAILED)));
 }
 
 /*------------------------------------------------------------------*/
 int error_no_network_support (void)
 {
- return (standard_error("No network support for this platform. Only Windows and UNIX have it."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_NONETWORKSUPPORT)));
 }
 
 /*------------------------------------------------------------------*/
 int error_unable_to_connect(void)
 {
-  return (standard_error("Unable to join the server. This can happen if it's not correctly set up, or if you are behind a firewall."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_UNABLETOCONNECT)));
 }
 
 /*------------------------------------------------------------------*/
 int error_not_a_liquidwar_server(void)
 {
-  return (standard_error("This server does not seem to be a Liquid War server."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_NOTALIQUIDWARSERVER)));
 }
 
 /*------------------------------------------------------------------*/
 int error_wrong_version(void)
 {
-  return (standard_error("Wrong client/server versions. Server and client must have the same version (this client's version is \"" LW_VERSION "\")."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_WRONGVERSION)));
 }
 
 /*------------------------------------------------------------------*/
 int error_network_problem(void)
 {
-  return (standard_error("A network error has occured. This often happens when the connection with the server is too slow or simply lost."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_NETWORKPROBLEM)));
 }
 
 /*------------------------------------------------------------------*/
 int error_cant_send_map(void)
 {
-  return (standard_error("Unable to send the map to the server."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_CANTSENDMAP)));
 }
 
 /*------------------------------------------------------------------*/
 int error_cant_receive_map(void)
 {
-  return (standard_error("Unable to receive the map from the server."));
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_CANTRECEIVEMAP)));
+}
+
+/*------------------------------------------------------------------*/
+int error_server_full(void)
+{
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_SERVERFULL)));
 }
 
 
