@@ -71,6 +71,8 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+static int LW_EXIT_FORCE_SHUTDOWN=0;
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -87,9 +89,9 @@ static void exit_all (void)
    * This is an attempt to get rid of a hideous bug under X-Win,
    * which said that there was a "bad file descriptor"
    */
-  rest(100);
+  rest(10);
   set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
-  rest(100);
+  rest(10);
 
   log_println();
   log_println_str ("Leaving Allegro (http://www.talula.demon.co.uk/allegro)");
@@ -199,14 +201,27 @@ static void disp_custom_fail_message (void)
 }
 
 /*------------------------------------------------------------------*/
-static void disp_integrity_message (void)
+static void disp_graphics_fail_message (void)
 {
-  log_println_str("Your \".exe\" or \".dat\" file has been modified");
+  log_println_str("Unable to set up a graphic mode.");
   log_println();
-  log_println_str("First check that \"lw.dat\" is in the \".\\data\\\" directory.");
-  log_println_str("If you used the \"lw -dat\" switch, check that the path is correct.");
-  log_println();
-  log_println_str("If this doesn't work, try and reload the original files from my web site.");
+  log_println_str("Liquid War _needs_ to set up a graphic mode.");
+  log_println_str("Please check that your config is supported by Allegro.");
+}
+
+/*------------------------------------------------------------------*/
+void my_exit_close_button (void)
+{
+  LW_EXIT_FORCE_SHUTDOWN=1;
+}
+
+/*------------------------------------------------------------------*/
+void my_exit_poll()
+{
+  if (LW_EXIT_FORCE_SHUTDOWN)
+    {
+      my_exit(EXIT_CODE_OK);
+    }
 }
 
 /*------------------------------------------------------------------*/
@@ -231,9 +246,6 @@ void my_exit (int code)
 	case EXIT_CODE_MEM_TROUBLE:
 	  disp_mem_trouble_message();
 	  break;
-	case EXIT_CODE_INTEGRITY:
-	  disp_integrity_message();
-	  break;
 	case EXIT_CODE_BIG_DATA:
 	  disp_big_data_message();
 	  break;
@@ -243,6 +255,9 @@ void my_exit (int code)
 	case EXIT_CODE_CUSTOM_FAIL:
 	  disp_custom_fail_message();
 	  break;
+	case EXIT_CODE_GRAPHICS_FAIL:
+	  disp_graphics_fail_message();
+	  break;
         }
 #ifdef ALLEGRO_DOS
       getch ();
