@@ -84,6 +84,7 @@
 #include "watchdog.h"
 #include "network.h"
 #include "lang.h"
+#include "exit.h"
 
 /*==================================================================*/
 /* definitions de constantes                                        */
@@ -158,23 +159,22 @@ static void init_cursor_control_method (void)
 {
   int i;
 
-  /*
-   * loop for all the possible teams, that's to say each of the
-   * 6 areas in the "teams" menu
-   */
+
   for (i=0;i<NB_TEAMS;++i)
     {
-      /*
-       * since network is not implemented, we consider that the
-       * cursor is not controled by the network
-       */
-      CURRENT_CURSOR[i].from_network=0;
-      /*
-       * we check the config to see wether the cursor is moved
-       * by a computer or a human.
-       */
-      CURRENT_CURSOR[i].cpu_or_human=
-	(CONFIG_CONTROL_TYPE[i]==CONFIG_CONTROL_TYPE_CPU);
+      if (LW_NETWORK_ON)
+	{
+	  CURRENT_CURSOR[i].from_network=LW_NETWORK_INFO[i].network;
+	  CURRENT_CURSOR[i].control_type=LW_NETWORK_INFO[i].control_type;	  
+	}
+      else
+	{
+	  /*
+	   * local teams
+	   */
+	  CURRENT_CURSOR[i].from_network=0;
+	  CURRENT_CURSOR[i].control_type=CONFIG_CONTROL_TYPE[i];
+	}
     }
 }
 
@@ -541,13 +541,6 @@ static void display(void)
    * entered, and does the required stuff if the answer is yes
    */
   check_code();
-  /*
-   * like check_code but dedicated to the info mode on/off
-   * ie it detects if F1 has been pressed and decides wether
-   * the info bar must be displayed or not
-   */
-  check_info_state();
-
   /*
    * keeps track of how long the mext operation takes
    */
@@ -558,6 +551,13 @@ static void display(void)
   fill_next_screen();
   stop_profile (DISP_PROFILE);
 
+  /*
+   * like check_code but dedicated to the info mode on/off
+   * ie it detects if F1 has been pressed and decides wether
+   * the info bar must be displayed or not
+   */
+  check_info_state();
+
   /*
    * we display the system messages if needed
    */
@@ -704,6 +704,11 @@ int game (void)
 	   */
 	  display();
 
+	  /*
+	   * Now we check if the "Close" button has been clicked
+	   */
+	  my_exit_poll();
+
 	  stop_profile (GLOBAL_PROFILE);
 	}
     }
