@@ -67,6 +67,7 @@ extern int GFX_MODE_H[5];
 /*==================================================================*/
 
 int need_to_change_mode(int res1,int res2,int flip);
-int set_resolution (int res, int flip, int fullscreen);
+int set_resolution (int res, int flip, int fullscreen, 
+		    int *flip_enabled);
 
 #endif
