@@ -56,33 +56,32 @@
 /*==================================================================*/
 
 #include <allegro.h>
+#include "asm.h"
 
 /*==================================================================*/
 /* types                                                            */
 /*==================================================================*/
 
-extern void draw_distor_line
-                         (BITMAP *next_screen,
-                          int current_area_w,
-                          int h,
-                          int x,
-                          int fp_y,
-                          int ip_y,
-                          int fp_x,
-                          int ip_x,
-                          int lim_h,
-                          int lim_w,
-                          int *fp_x0,
-                          int *x_corres,
-                          int *WAVE_SHAPE_HY,
-                          int **WAVE_SHAPE_Y_CORRES,
-                          char *src,
-                          int mode_x,
-                          int temp1,
-                          int temp2,
-                          int temp3,
-                          int temp4,
-                          int temp5);
+extern void LW_ASM_FUNC draw_distor_line (BITMAP *distorsion_target,
+					 int current_area_w,
+					 int w,
+					 int u,
+					 int fp_x,
+					 int ip_x,
+					 int fp_y,
+					 int ip_y,
+					 int lim_w,
+					 int lim_h,
+					 int *fp_x0,
+					 int *y_corres,
+					 int *WAVE_SHAPE_WX,
+					 int **WAVE_SHAPE_X_CORRES,
+					 char *src,
+					 int temp1,
+					 int temp2,
+					 int temp3,
+					 int temp4,
+					 int temp5);
   
 #endif
 
