@@ -145,109 +145,112 @@
 #define LW_LANG_STRING_ADVANCED_BASEHEALTH        58
 #define LW_LANG_STRING_ADVANCED_WINNERHELP        59
 #define LW_LANG_STRING_ADVANCED_CPUSTRENGTH       60
+#define LW_LANG_STRING_ADVANCED_ASMALGORITHM      61
+#define LW_LANG_STRING_ADVANCED_YES               62
+#define LW_LANG_STRING_ADVANCED_NO                63
 
-#define LW_LANG_STRING_SPEEDS_CURSOR              61
-#define LW_LANG_STRING_SPEEDS_FPS                 62
-#define LW_LANG_STRING_SPEEDS_NOFPSLIMIT          63
-#define LW_LANG_STRING_SPEEDS_RPS                 64
-#define LW_LANG_STRING_SPEEDS_NORPSLIMIT          65
+#define LW_LANG_STRING_SPEEDS_CURSOR              64
+#define LW_LANG_STRING_SPEEDS_FPS                 65
+#define LW_LANG_STRING_SPEEDS_NOFPSLIMIT          66
+#define LW_LANG_STRING_SPEEDS_RPS                 67
+#define LW_LANG_STRING_SPEEDS_NORPSLIMIT          68
 
-#define LW_LANG_STRING_CONTROLS_JOYSTICK          66          
-#define LW_LANG_STRING_CONTROLS_OFF               67
-#define LW_LANG_STRING_CONTROLS_2JOYSTICKS        68
-#define LW_LANG_STRING_CONTROLS_4BUTTONS          69
-#define LW_LANG_STRING_CONTROLS_STANDARD          70
-#define LW_LANG_STRING_CONTROLS_MOUSESENSIB       71
+#define LW_LANG_STRING_CONTROLS_JOYSTICK          69          
+#define LW_LANG_STRING_CONTROLS_OFF               70
+#define LW_LANG_STRING_CONTROLS_2JOYSTICKS        71
+#define LW_LANG_STRING_CONTROLS_4BUTTONS          72
+#define LW_LANG_STRING_CONTROLS_STANDARD          73
+#define LW_LANG_STRING_CONTROLS_MOUSESENSIB       74
 
-#define LW_LANG_STRING_ABOUT_CREDITS              72
-#define LW_LANG_STRING_ABOUT_COPYRIGHT            73
-#define LW_LANG_STRING_ABOUT_LICENSE              74
-#define LW_LANG_STRING_ABOUT_VERSION              75
+#define LW_LANG_STRING_ABOUT_CREDITS              75
+#define LW_LANG_STRING_ABOUT_COPYRIGHT            76
+#define LW_LANG_STRING_ABOUT_LICENSE              77
+#define LW_LANG_STRING_ABOUT_VERSION              78
 
-#define LW_LANG_STRING_INTERNET_REFRESH           76
-#define LW_LANG_STRING_INTERNET_JOINNOW           77
-#define LW_LANG_STRING_INTERNET_PORT              78
-#define LW_LANG_STRING_INTERNET_PASSWORD          79
-#define LW_LANG_STRING_INTERNET_YES               80
-#define LW_LANG_STRING_INTERNET_NO                81
-#define LW_LANG_STRING_INTERNET_UPTIME            82
-#define LW_LANG_STRING_INTERNET_DAYS              83
-#define LW_LANG_STRING_INTERNET_DAY               84
-#define LW_LANG_STRING_INTERNET_HOURS             85
-#define LW_LANG_STRING_INTERNET_MINUTES           86
-#define LW_LANG_STRING_INTERNET_SECONDS           87
+#define LW_LANG_STRING_INTERNET_REFRESH           79
+#define LW_LANG_STRING_INTERNET_JOINNOW           80
+#define LW_LANG_STRING_INTERNET_PORT              81
+#define LW_LANG_STRING_INTERNET_PASSWORD          82
+#define LW_LANG_STRING_INTERNET_YES               83
+#define LW_LANG_STRING_INTERNET_NO                84
+#define LW_LANG_STRING_INTERNET_UPTIME            85
+#define LW_LANG_STRING_INTERNET_DAYS              86
+#define LW_LANG_STRING_INTERNET_DAY               87
+#define LW_LANG_STRING_INTERNET_HOURS             88
+#define LW_LANG_STRING_INTERNET_MINUTES           89
+#define LW_LANG_STRING_INTERNET_SECONDS           90
 
-#define LW_LANG_STRING_WAVE_AMPLI                 88
-#define LW_LANG_STRING_WAVE_NUMBER                89
-#define LW_LANG_STRING_WAVE_SPEED                 90
-#define LW_LANG_STRING_WAVE_WX                    91
-#define LW_LANG_STRING_WAVE_HY                    92
-#define LW_LANG_STRING_WAVE_WY                    93
-#define LW_LANG_STRING_WAVE_HX                    94
+#define LW_LANG_STRING_WAVE_AMPLI                 91
+#define LW_LANG_STRING_WAVE_NUMBER                92
+#define LW_LANG_STRING_WAVE_SPEED                 93
+#define LW_LANG_STRING_WAVE_WX                    94
+#define LW_LANG_STRING_WAVE_HY                    95
+#define LW_LANG_STRING_WAVE_WY                    96
+#define LW_LANG_STRING_WAVE_HX                    97
 
-#define LW_LANG_STRING_CONNECT_STARTNOW           95
-#define LW_LANG_STRING_CONNECT_WAITING            96
-#define LW_LANG_STRING_CONNECT_WAITINGFOR         97
-#define LW_LANG_STRING_CONNECT_TEAMS              98
+#define LW_LANG_STRING_CONNECT_STARTNOW           98
+#define LW_LANG_STRING_CONNECT_WAITING            99
+#define LW_LANG_STRING_CONNECT_WAITINGFOR        100
+#define LW_LANG_STRING_CONNECT_TEAMS             101
 
-#define LW_LANG_STRING_NETPLAY_CONNECT            99
-#define LW_LANG_STRING_NETPLAY_PING              100
-#define LW_LANG_STRING_NETPLAY_CHECKPROGRAM      101
-#define LW_LANG_STRING_NETPLAY_CHECKVERSION      102
-#define LW_LANG_STRING_NETPLAY_FREETEAMS         103
-#define LW_LANG_STRING_NETPLAY_RESERVETEAMS      104
-#define LW_LANG_STRING_NETPLAY_SENDCONFIG        105
-#define LW_LANG_STRING_NETPLAY_SENDMAP           106
-#define LW_LANG_STRING_NETPLAY_WAITING           107
-#define LW_LANG_STRING_NETPLAY_WHOPLAYS          108
-#define LW_LANG_STRING_NETPLAY_RECVCONFIG        109
-#define LW_LANG_STRING_NETPLAY_RECVMAP           110
+#define LW_LANG_STRING_NETPLAY_CONNECT           102
+#define LW_LANG_STRING_NETPLAY_PING              103
+#define LW_LANG_STRING_NETPLAY_CHECKPROGRAM      104
+#define LW_LANG_STRING_NETPLAY_CHECKVERSION      105
+#define LW_LANG_STRING_NETPLAY_FREETEAMS         106
+#define LW_LANG_STRING_NETPLAY_RESERVETEAMS      107
+#define LW_LANG_STRING_NETPLAY_SENDCONFIG        108
+#define LW_LANG_STRING_NETPLAY_SENDMAP           109
+#define LW_LANG_STRING_NETPLAY_WAITING           110
+#define LW_LANG_STRING_NETPLAY_WHOPLAYS          111
+#define LW_LANG_STRING_NETPLAY_RECVCONFIG        112
+#define LW_LANG_STRING_NETPLAY_RECVMAP           113
 
-#define LW_LANG_STRING_CODE_FPS                  111
-#define LW_LANG_STRING_CODE_RPS                  112
-#define LW_LANG_STRING_CODE_PERCENTCALC          113
-#define LW_LANG_STRING_CODE_PERCENTDISPLAY       114
-#define LW_LANG_STRING_CODE_SPREADGRADTIME       115
-#define LW_LANG_STRING_CODE_MOVEARMYTIME         116
-#define LW_LANG_STRING_CODE_DISPLAYTIME          117
-#define LW_LANG_STRING_CODE_FLIPTIME             118
-#define LW_LANG_STRING_CODE_OTHERCALCTIME        119
-#define LW_LANG_STRING_CODE_GLOBALTIME           120
-#define LW_LANG_STRING_CODE_STANDARDDISPLAY      121
-#define LW_LANG_STRING_CODE_GRADIENT1            122
-#define LW_LANG_STRING_CODE_GRADIENT2            123
-#define LW_LANG_STRING_CODE_GRADIENT3            124
-#define LW_LANG_STRING_CODE_GRADIENT4            125
-#define LW_LANG_STRING_CODE_GRADIENT5            126
-#define LW_LANG_STRING_CODE_GRADIENT6            127
-#define LW_LANG_STRING_CODE_MESHSIZE             128
-#define LW_LANG_STRING_CODE_MESHSTRUCTURE        129
-#define LW_LANG_STRING_CODE_PAUSEOFF             130
-#define LW_LANG_STRING_CODE_PAUSEON              131
-#define LW_LANG_STRING_CODE_WAVEEFFECTSOFF       132
-#define LW_LANG_STRING_CODE_WAVEEFFECTSON        133
+#define LW_LANG_STRING_CODE_FPS                  114
+#define LW_LANG_STRING_CODE_RPS                  115
+#define LW_LANG_STRING_CODE_PERCENTCALC          116
+#define LW_LANG_STRING_CODE_PERCENTDISPLAY       117
+#define LW_LANG_STRING_CODE_SPREADGRADTIME       118
+#define LW_LANG_STRING_CODE_MOVEARMYTIME         119
+#define LW_LANG_STRING_CODE_DISPLAYTIME          120
+#define LW_LANG_STRING_CODE_FLIPTIME             121
+#define LW_LANG_STRING_CODE_OTHERCALCTIME        122
+#define LW_LANG_STRING_CODE_GLOBALTIME           123
+#define LW_LANG_STRING_CODE_STANDARDDISPLAY      124
+#define LW_LANG_STRING_CODE_GRADIENT1            125
+#define LW_LANG_STRING_CODE_GRADIENT2            126
+#define LW_LANG_STRING_CODE_GRADIENT3            127
+#define LW_LANG_STRING_CODE_GRADIENT4            128
+#define LW_LANG_STRING_CODE_GRADIENT5            129
+#define LW_LANG_STRING_CODE_GRADIENT6            130
+#define LW_LANG_STRING_CODE_MESHSIZE             131
+#define LW_LANG_STRING_CODE_MESHSTRUCTURE        132
+#define LW_LANG_STRING_CODE_PAUSEOFF             133
+#define LW_LANG_STRING_CODE_PAUSEON              134
+#define LW_LANG_STRING_CODE_WAVEEFFECTSOFF       135
+#define LW_LANG_STRING_CODE_WAVEEFFECTSON        136
 
-#define LW_LANG_STRING_SCORE_WINNER              134
+#define LW_LANG_STRING_SCORE_WINNER              137
 
-#define LW_LANG_STRING_GAME_BACKMEMFAIL          135
-#define LW_LANG_STRING_GAME_DISPMEMFAIL          136
-#define LW_LANG_STRING_GAME_MESHMEMFAIL          137
-#define LW_LANG_STRING_GAME_AREAMEMFAIL          138
-#define LW_LANG_STRING_GAME_ARMYMEMFAIL          139
+#define LW_LANG_STRING_GAME_BACKMEMFAIL          138
+#define LW_LANG_STRING_GAME_DISPMEMFAIL          139
+#define LW_LANG_STRING_GAME_MESHMEMFAIL          140
+#define LW_LANG_STRING_GAME_AREAMEMFAIL          141
+#define LW_LANG_STRING_GAME_ARMYMEMFAIL          142
 
-#define LW_LANG_STRING_ERROR_NOTENOUGHTEAMS      140
-#define LW_LANG_STRING_ERROR_NOTENOUGHBIGDATA    141
-#define LW_LANG_STRING_ERROR_GRAPHICSINITFAILED  142
-#define LW_LANG_STRING_ERROR_NONETWORKSUPPORT    143
-#define LW_LANG_STRING_ERROR_UNABLETOCONNECT     144
-#define LW_LANG_STRING_ERROR_NOTALIQUIDWARSERVER 145 
-#define LW_LANG_STRING_ERROR_WRONGVERSION        146
-#define LW_LANG_STRING_ERROR_NETWORKPROBLEM      147
-#define LW_LANG_STRING_ERROR_CANTSENDMAP         148
-#define LW_LANG_STRING_ERROR_CANTRECEIVEMAP      149
-#define LW_LANG_STRING_ERROR_SERVERFULL          150
+#define LW_LANG_STRING_ERROR_NOTENOUGHTEAMS      143
+#define LW_LANG_STRING_ERROR_NOTENOUGHBIGDATA    144
+#define LW_LANG_STRING_ERROR_GRAPHICSINITFAILED  145
+#define LW_LANG_STRING_ERROR_NONETWORKSUPPORT    146
+#define LW_LANG_STRING_ERROR_UNABLETOCONNECT     147
+#define LW_LANG_STRING_ERROR_NOTALIQUIDWARSERVER 148 
+#define LW_LANG_STRING_ERROR_WRONGVERSION        149
+#define LW_LANG_STRING_ERROR_NETWORKPROBLEM      150
+#define LW_LANG_STRING_ERROR_CANTSENDMAP         151
+#define LW_LANG_STRING_ERROR_CANTRECEIVEMAP      152
+#define LW_LANG_STRING_ERROR_SERVERFULL          153
 
-#define LW_LANG_NB_STRINGS                       151
+#define LW_LANG_NB_STRINGS                       154
 
 /*==================================================================*/
 /* globals                                                          */
