@@ -394,7 +394,7 @@ static void box_for_choose_map (void)
   /* caduque depuis que my_slider fait tout tout seul */
 
   dp=init_dialog (d,0);
-  update_dialog (dp);
+  my_update_dialog (dp);
   shutdown_dialog (dp);
 }
 
@@ -429,9 +429,6 @@ int choose_map (void)
   d[6].dp2=slider_bg;
   d[4].dp3=d[5].dp3=d[6].dp3=d;
   d[4].flags=d[5].flags=d[6].flags=0;
-  //#ifdef ALLEGRO_WINDOWS
-  //d[4].flags=d[5].flags=d[6].flags=D_HIDDEN;
-  //#endif
   d[4].d1=RAW_MAP_NUMBER-1;
   d[5].d1=d[6].d1=RAW_TEXTURE_NUMBER-1;
   d[4].d2=CONFIG_LEVEL_MAP;
