@@ -61,6 +61,7 @@
 #include "map.h"
 #include "texture.h"
 #include "network.h"
+#include "log.h"
 
 /*==================================================================*/
 /* constantes                                                       */
@@ -129,7 +130,7 @@ static BITMAP *extract_significant_part (BITMAP *src)
     result=NULL;
   else
     {
-      result=create_bitmap (dst_w, dst_h);
+      result=my_create_bitmap (dst_w, dst_h);
       if (result)
 	blit (src, result, dst_x, dst_y, 0, 0, dst_w, dst_h);
     }
@@ -327,7 +328,8 @@ void *archive_raw_map (const char *filename)
   int i,w=0,h=0,size,bg_size;
   BITMAP *bmp,*sub_bmp;
   PALETTE pal;
-  char *temp=NULL,*result=NULL;
+  char *temp=NULL;
+  char *result=NULL;
   short *ptr_wh;
   int *ptr_bg;
   char readable_name_buffer[LW_MAP_READABLE_NAME_SIZE+1];
