@@ -116,7 +116,7 @@ void main_menu (void)
   display_back_image ();
   /*
     dp=init_dialog (d,4);
-    update_dialog (dp);
+    my_update_dialog (dp);
     shutdown_dialog (dp);
   */
   my_fade_in ();
