@@ -68,41 +68,45 @@
 /*==================================================================*/
 
 typedef union
-        {
-         int time;
-         struct
-          {
-           short x;
-           short y;
-          } cursor;
-        } MESH_UPDATE;
+{
+  int time;
+  struct
+  {
+    short x;
+    short y;
+  } cursor;
+} MESH_UPDATE;
 
 typedef struct
-        {
-         int dir :8;
-         int grad:24;
-        } MESH_STATE;
+{
+  int dir :8;
+  int grad:24;
+} MESH_STATE;
 
 typedef struct
-        {
-         MESH_UPDATE update;
-         MESH_STATE state;
-        } MESH_INFO;
+{
+  MESH_UPDATE update;
+  MESH_STATE state;
+} MESH_INFO;
 
 typedef struct
-        {
-         char decal_for_dir :8;
-         int  size          :24;
-        } MESH_SIDE;
+{
+  // char decal_for_dir :8; -> causes GPF under Win32.
+  // MSVC allocates 64 bits for the struct if decal_for_dir
+  // is declared as a char, and 32 bit if it's declared
+  // as an int. Go figure...
+  int  decal_for_dir :8;
+  int  size          :24;
+} MESH_SIDE;
 
 typedef struct
-        {
-         short x;
-         short y;
-         MESH_SIDE side;
-         MESH_INFO info[NB_TEAMS];
-         void *link[NB_DIRS];
-        } MESH;
+{
+  short x;
+  short y;
+  MESH_SIDE side;
+  MESH_INFO info[NB_TEAMS];
+  void *link[NB_DIRS];
+} MESH;
 
 /*==================================================================*/
 /* variables globales                                               */
