@@ -87,11 +87,27 @@
  * checks and then launches the game function located in game.c
  */
 int play_sequence (void)
+{
+  int result;
+
+  lw_config_set_current_rules_to_default ();
+
+  result=play_sequence_ex ();
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * Internal version of play_sequence, used for network games
+ */
+int play_sequence_ex (void)
 {
   char *message;
   int result,retour=0;
   DIALOG d[2];
   DIALOG_PLAYER *dp;
+  int flip_enabled=0;
 
   memset(d,0,sizeof(d));
 
@@ -111,7 +127,7 @@ int play_sequence (void)
    * message is actually blitted on the screen
    */
   dp=init_dialog (d,0);
-  update_dialog (dp);
+  my_update_dialog (dp);
   shutdown_dialog (dp);
 
   /*
@@ -134,115 +150,120 @@ int play_sequence (void)
    * if there's only one team selected we stop right away and quit
    */
   if (PLAYING_TEAMS<2)
-  {
-     free_game_memory();
-     error_not_enough_teams();
-  }
-   else
-  {
-  /*
-   * we launch init_game from the game module, this function may fail
-   * and if it does it returns a string containing the error message
-   */
-  if (!(message=init_game()))
     {
-     /*
-      * we set up the sound of waves a little louder so that the player
-      * understands he's playing *now*
-      */
-     WATER_VOLUME=CONFIG_WATER_VOLUME_GAME;
-     /*
-      * fade out cause we're going to switch video modes
-      */
-     my_fade_out ();
-
-     /*
-      * we change the resolution, but only if the game resolution is
-      * actually different from the menu resolution
-      */
-     if (need_to_change_mode(CONFIG_GFX_GAME,CONFIG_GFX_MENU,CONFIG_PAGE_FLIP))
-		result=set_resolution (CONFIG_GFX_GAME,
-				CONFIG_PAGE_FLIP,
-				CONFIG_FULLSCREEN);
-
-     lw_mouse_hide();
-
-     /*
-      * the blank round function initializes the double-buffer system
-      * and the main display target, it might fail because of lacking memory
-      */
-     if (!blank_round())
-     {
-      /*
-       * fiat lux
-       */
-      my_fade_in ();
-
-      /*
-       * start playing some music
-       */
-      start_music();
-
-      /*
-       * OK, here we go, let's enter the main game loop
-       */
-      game ();
-
-      /*
-       * stop the music
-       */
-      stop_music();
-     }
-
-     /*
-      * let's be clean 8-)
-      */
-     free_game_memory();
-     
-     /*
-      * we close the network socket abruptly
-      */
-     lw_sock_close(&LW_KEYEXCH_SOCK);
-
-     /*
-      * we turn the volume down
-      */
-     WATER_VOLUME=CONFIG_WATER_VOLUME_MENU;
-
-     /*
-      * fade out before video mode switching
-      */
-     my_fade_out();
-     /*
-      * again, we change the video mode only if it is really required
-      */
-     if (need_to_change_mode(CONFIG_GFX_GAME,CONFIG_GFX_MENU,CONFIG_PAGE_FLIP))
-		result=set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN);
-
-     lw_mouse_show();
-
-     /*
-      * displays the 3 tubes with the score
-      */
-     retour=display_scores ();
+      free_game_memory();
+      error_not_enough_teams();
     }
   else
     {
-     /*
-      * the main reason why init_game should fail is a lack of big data
-      * this can be cured by selecting a smaller level or increasing the
-      * amount of data reserved at startup (command line parameter)
-      */
-     free_game_memory();
+      /*
+       * we launch init_game from the game module, this function may fail
+       * and if it does it returns a string containing the error message
+       */
+      if (!(message=init_game()))
+	{
+	  /*
+	   * we set up the sound of waves a little louder so that the player
+	   * understands he's playing *now*
+	   */
+	  WATER_VOLUME=CONFIG_WATER_VOLUME_GAME;
+	  /*
+	   * fade out cause we're going to switch video modes
+	   */
+	  my_fade_out ();
 
-     /*
-      * we close the network socket abruptly
-      */
-     lw_sock_close(&LW_KEYEXCH_SOCK);
+	  /*
+	   * we change the resolution, but only if the game resolution is
+	   * actually different from the menu resolution
+	   */
+	  if (need_to_change_mode(CONFIG_GFX_GAME,
+				  CONFIG_GFX_MENU,
+				  CONFIG_PAGE_FLIP))
+	    result=set_resolution (CONFIG_GFX_GAME,
+				   CONFIG_PAGE_FLIP,
+				   CONFIG_FULLSCREEN,
+				   &flip_enabled);
 
-     error_not_enough_big_data ();
+	  lw_mouse_hide();
+
+	  /*
+	   * the blank round function initializes the double-buffer system
+	   * and the main display target, it might fail because of lacking memory
+	   */
+	  if (!blank_round())
+	    {
+	      /*
+	       * fiat lux
+	       */
+	      my_fade_in ();
+
+	      /*
+	       * start playing some music
+	       */
+	      start_music();
+
+	      /*
+	       * OK, here we go, let's enter the main game loop
+	       */
+	      game ();
+
+	      /*
+	       * stop the music
+	       */
+	      stop_music();
+	    }
+
+	  /*
+	   * let's be clean 8-)
+	   */
+	  free_game_memory();
+     
+	  /*
+	   * we close the network socket abruptly
+	   */
+	  lw_sock_close(&LW_KEYEXCH_SOCK);
+
+	  /*
+	   * we turn the volume down
+	   */
+	  WATER_VOLUME=CONFIG_WATER_VOLUME_MENU;
+
+	  /*
+	   * fade out before video mode switching
+	   */
+	  my_fade_out();
+	  /*
+	   * again, we change the video mode only if it is really required
+	   */
+	  if (need_to_change_mode(CONFIG_GFX_GAME,
+				  CONFIG_GFX_MENU,
+				  CONFIG_PAGE_FLIP && flip_enabled))
+	    result=set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN,NULL);
+
+	  lw_mouse_show();
+
+	  /*
+	   * displays the 3 tubes with the score
+	   */
+	  retour=display_scores ();
+	}
+      else
+	{
+	  /*
+	   * the main reason why init_game should fail is a lack of big data
+	   * this can be cured by selecting a smaller level or increasing the
+	   * amount of data reserved at startup (command line parameter)
+	   */
+	  free_game_memory();
+
+	  /*
+	   * we close the network socket abruptly
+	   */
+	  lw_sock_close(&LW_KEYEXCH_SOCK);
+
+	  error_not_enough_big_data ();
+	}
     }
-  }
 
   return retour;
 }
