@@ -201,12 +201,17 @@ int lw_protocol_ask_free_teams (int sock,int *nb)
 /*
  * Inform the server that this player will be playing.
  */
-int lw_protocol_reserve_team (int sock, int num, char *name)
+int lw_protocol_reserve_team (int sock, int num, 
+			      int control_type, char *name)
 {
   int result=0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(message,"%s %d,'%s'",LW_NETMESS_TEXT_TEAM,num,name);
+  sprintf(message,"%s %d,%d,'%s'",
+	  LW_NETMESS_TEXT_TEAM,
+	  num,
+	  control_type,
+	  name);
   if (lw_sock_send_str(sock,message))
     {
       if (recv_ok(sock))
@@ -264,11 +269,12 @@ int lw_protocol_ask_who (int sock,
 		   * flag is set to 1 in the "NETWORK" case.
 		   */
 		case LW_NETMESS_CODE_LOCAL:
-		  if (netmess->argc>=1 && netmess->argc==2)
+		  if (netmess->argc==3)
 		    {
 		      who->active=1;
 		      who->server_id=atoi(netmess->argv[0]);
-		      strncpy(who->name,netmess->argv[1],NAME_SIZE);
+		      who->control_type=atoi(netmess->argv[1]);
+		      strncpy(who->name,netmess->argv[2],NAME_SIZE);
 		      who->name[NAME_SIZE]='\0';
 		      result=1;
 		    }
@@ -337,14 +343,8 @@ int lw_protocol_send_config (int sock)
 
   if (lw_sock_send_str(sock,LW_NETMESS_TEXT_SENDCONFIG))
     {
-      config.cursor_increase_speed=CONFIG_CURSOR_INCREASE_SPEED;
-      config.fighter_attack=CONFIG_FIGHTER_ATTACK;
-      config.fighter_defense=CONFIG_FIGHTER_DEFENSE;
-      config.fighter_new_health=CONFIG_FIGHTER_NEW_HEALTH;
-      config.number_influence=CONFIG_NUMBER_INFLUENCE;
-      config.fighter_number=CONFIG_FIGHTER_NUMBER;
-      config.game_time=CONFIG_GAME_TIME;
-      config.cpu_advantage=CONFIG_CPU_ADVANTAGE;
+
+      memcpy(&config,&LW_CONFIG_CURRENT_RULES,sizeof(LW_NETCONF));
 
       if (lw_netconf_send(sock,&config))
 	{
@@ -373,14 +373,7 @@ int lw_protocol_recv_config (int sock)
 	{
 	  if (recv_ok(sock))
 	    {
-	      CONFIG_CURSOR_INCREASE_SPEED=config.cursor_increase_speed;
-	      CONFIG_FIGHTER_ATTACK=config.fighter_attack;
-	      CONFIG_FIGHTER_DEFENSE=config.fighter_defense;
-	      CONFIG_FIGHTER_NEW_HEALTH=config.fighter_new_health;
-	      CONFIG_NUMBER_INFLUENCE=config.number_influence;
-	      CONFIG_FIGHTER_NUMBER=config.fighter_number;
-	      CONFIG_GAME_TIME=config.game_time;
-	      CONFIG_CPU_ADVANTAGE=config.cpu_advantage;
+	      memcpy(&LW_CONFIG_CURRENT_RULES,&config,sizeof(LW_NETCONF));
 
 	      result=1;
 	    }
