@@ -70,7 +70,8 @@ int lw_protocol_do_ping (int sock);
 int lw_protocol_tell_version (int sock, char *version);
 int lw_protocol_tell_program (int sock, char *program);
 int lw_protocol_ask_free_teams (int sock, int *nb);
-int lw_protocol_reserve_team (int sock, int num, char *name);
+int lw_protocol_reserve_team (int sock, int num, 
+			      int control_type, char *name);
 int lw_protocol_ask_who (int sock, 
 			 int num,
 			 LW_WHO *who);
