@@ -299,7 +299,7 @@ int display_scores (void)
 
   display_back_image ();
   dp=init_dialog (d,0);
-  update_dialog (dp);
+  my_update_dialog (dp);
   shutdown_dialog (dp);
 
   my_fade_in();
@@ -312,7 +312,7 @@ int display_scores (void)
       if (!last_draw_done)
 	{
 	  dp=init_dialog (d,choix);
-	  while (update_dialog (dp) && !last_draw_done)
+	  while (my_update_dialog (dp) && !last_draw_done)
 	    {
 	      scare_mouse();
 	      diff_ticker=get_ticker()-first_ticker;
