@@ -63,6 +63,7 @@
 #include "rules.h"
 #include "sound.h"
 #include "time.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -75,92 +76,109 @@
 /*------------------------------------------------------------------*/
 static void write_cis_setting (DIALOG *d)
 {
- char *str;
+  char *str;
 
- str=d->dp;
- sprintf (str,"Cursor x%d",CONFIG_CURSOR_INCREASE_SPEED+1);
+  str=d->dp;
+  sprintf (str,
+	   "%s x%d",
+	   lw_lang_string(LW_LANG_STRING_SPEEDS_CURSOR),
+	   CONFIG_CURSOR_INCREASE_SPEED+1);
 }
 
 /*------------------------------------------------------------------*/
 static int slider_cis (void *dp3, int d2)
 {
- DIALOG *d;
+  DIALOG *d;
 
- d=dp3;
+  d=dp3;
 
- CONFIG_CURSOR_INCREASE_SPEED=d2;
- write_cis_setting (d);
- my_textbox_proc (MSG_DRAW, d, 0);
+  CONFIG_CURSOR_INCREASE_SPEED=d2;
+  write_cis_setting (d);
 
- play_click ();
+  scare_mouse();
+  my_textbox_proc (MSG_DRAW, d, 0);
+  unscare_mouse();
 
- return 0;
+  play_click ();
+
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
 static void write_fps_setting (DIALOG *d)
 {
- char *str;
+  char *str;
 
- str=d->dp;
- if (DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]!=0)
-   {
-     sprintf (str,"%d frames/s",
-	      1000/(DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]));
-   }
- else
-   {
-     sprintf(str,"No fps limit");
-   }
+  str=d->dp;
+  if (DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]!=0)
+    {
+      sprintf (str,
+	       "%d %s",
+	       1000/(DISPLAY_DELAY_MIN[CONFIG_FRAMES_PER_SEC_LIMIT]),
+	       lw_lang_string(LW_LANG_STRING_SPEEDS_FPS));
+    }
+  else
+    {
+      sprintf(str,
+	      lw_lang_string(LW_LANG_STRING_SPEEDS_NOFPSLIMIT));
+    }
 }
 
 /*------------------------------------------------------------------*/
 static int slider_fps (void *dp3, int d2)
 {
- DIALOG *d;
+  DIALOG *d;
 
- d=dp3;
+  d=dp3;
 
- CONFIG_FRAMES_PER_SEC_LIMIT=d2;
- write_fps_setting (d);
- my_textbox_proc (MSG_DRAW, d, 0);
+  CONFIG_FRAMES_PER_SEC_LIMIT=d2;
+  write_fps_setting (d);
 
- play_click ();
+  scare_mouse();
+  my_textbox_proc (MSG_DRAW, d, 0);
+  unscare_mouse();
 
- return 0;
+  play_click ();
+
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
 static void write_rps_setting (DIALOG *d)
 {
- char *str;
+  char *str;
 
- str=d->dp;
- if (LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT]!=0)
-   {
-     sprintf (str,"%d rounds/s",
-	      1000/(LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT]));
-   }
- else
-   {
-     sprintf(str,"No rps limit");
-   }
+  str=d->dp;
+  if (LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT]!=0)
+    {
+      sprintf (str,"%d %s",
+	       1000/(LOGIC_DELAY_MIN[CONFIG_ROUNDS_PER_SEC_LIMIT]),
+	       lw_lang_string(LW_LANG_STRING_SPEEDS_RPS));
+    }
+  else
+    {
+      sprintf(str,
+	      lw_lang_string(LW_LANG_STRING_SPEEDS_NORPSLIMIT));
+    }
 }
 
 /*------------------------------------------------------------------*/
 static int slider_rps (void *dp3, int d2)
 {
- DIALOG *d;
+  DIALOG *d;
 
- d=dp3;
+  d=dp3;
 
- CONFIG_ROUNDS_PER_SEC_LIMIT=d2;
- write_rps_setting (d);
- my_textbox_proc (MSG_DRAW, d, 0);
+  CONFIG_ROUNDS_PER_SEC_LIMIT=d2;
+  write_rps_setting (d);
 
- play_click ();
+  scare_mouse();
+  my_textbox_proc (MSG_DRAW, d, 0);
+  unscare_mouse();
 
- return 0;
+  play_click ();
+
+  return 0;
 }
 
 /*------------------------------------------------------------------*/
@@ -173,16 +191,18 @@ int speeds_options (void)
   char fps_buffer[30];
   char rps_buffer[30];
   
+  memset(d,0,sizeof(d));
+
   for (i=0; i<3; ++i)
-      {
-       standard_button (d+i+4,0,i,2,3);
-       d[i+4].proc=my_textbox_proc;
-      }
+    {
+      standard_button (d+i+4,0,i,2,3);
+      d[i+4].proc=my_textbox_proc;
+    }
   for (i=0; i<3; ++i)
-      {
-       standard_button (d+i+7,1,i,2,3);
-       d[i+7].proc=my_slider_proc;
-      }
+    {
+      standard_button (d+i+7,1,i,2,3);
+      d[i+7].proc=my_slider_proc;
+    }
 
   quick_buttons(d);
   d[4].dp=cis_buffer;
@@ -195,13 +215,13 @@ int speeds_options (void)
   d[8].dp3=&CONFIG_FRAMES_PER_SEC_LIMIT;
   d[9].dp3=&CONFIG_ROUNDS_PER_SEC_LIMIT;
   for (i=0;i<3;++i)
-      {
-       d[i+7].dp=NULL;
-       d[i+7].dp2=slider_int;
-       temp=d[i+7].dp3;
-       d[i+7].d2=*temp;
-       d[i+7].dp3=d+i+4;
-      }
+    {
+      d[i+7].dp=NULL;
+      d[i+7].dp2=slider_int;
+      temp=d[i+7].dp3;
+      d[i+7].d2=*temp;
+      d[i+7].dp3=d+i+4;
+    }
 
   d[7].dp2=slider_cis; 
   d[8].dp2=slider_fps; 
@@ -214,30 +234,30 @@ int speeds_options (void)
   d[10].proc=0;
 
   while (retour==0)
-        {
-          choix=my_do_dialog (d,choix);
-          switch (choix)
-            {
-             case -1:
-             case MENU_QUICK_BACK:
-                  retour=1;
-                  break;
-             case MENU_QUICK_MAIN:
-                  retour=MENU_TOP;
-                  break;
-             case MENU_QUICK_QUIT:
-                  if (confirm_quit())
-                    retour=MENU_EXIT;
-                  break;
-             case MENU_QUICK_HELP:
-                  retour=display_help (HELP_TEXT_SPEEDS);
-                  break;
-             }
-        }
+    {
+      choix=my_do_dialog (d,choix);
+      switch (choix)
+	{
+	case -1:
+	case MENU_QUICK_BACK:
+	  retour=1;
+	  break;
+	case MENU_QUICK_MAIN:
+	  retour=MENU_TOP;
+	  break;
+	case MENU_QUICK_QUIT:
+	  if (confirm_quit())
+	    retour=MENU_EXIT;
+	  break;
+	case MENU_QUICK_PLAY:
+	  retour=MENU_PLAY;
+	  break;
+	}
+    }
 
   if (retour>0)
     retour--;
 
- return retour;
+  return retour;
 }
 
