@@ -105,6 +105,7 @@ static void reset(LW_SRVCHAN *chan)
   chan->ready_ok=0;
   chan->start=0;
   chan->map=NULL;
+  memset(&(chan->config),0,sizeof(LW_NETCONF));
   for (i=0;i<NB_TEAMS;++i)
     {
       lw_srvteam_reset(&(chan->team[i]));
@@ -271,12 +272,13 @@ static int handle_team(LW_SRVCHAN *chan, LW_NETMESS *mess,
   int result=0;
   int i;
 
-  if (mess->argc==2)
+  if (mess->argc==3)
     {
       /*
-       * OK, there are 2 arguments
-       * - arg 1 is the team inde
-       * - arg 2 is the team name
+       * OK, there are 3 arguments
+       * - arg 1 is the team index
+       * - arg 2 is the "control_type" parameter 
+       * - arg 3 is the team name
        */
       i=atoi(mess->argv[0]);
       if (i>=0 && i<NB_TEAMS)
@@ -300,11 +302,12 @@ static int handle_team(LW_SRVCHAN *chan, LW_NETMESS *mess,
 		  (*free_teams)--;
 		  chan->team[i].active=1;
 
-		  strncpy(chan->team[i].name,mess->argv[1],NAME_SIZE);
+		  chan->team[i].control_type=atoi(mess->argv[1]);
+		  strncpy(chan->team[i].name,mess->argv[2],NAME_SIZE);
 		  chan->team[i].name[NAME_SIZE]='\0';
 
 		  log_print_str("Team \"");
-		  log_print_str(mess->argv[1]);
+		  log_print_str(mess->argv[2]);
 		  log_print_str("\" on client \"");
 		  log_print_str(chan->ip);
 		  log_print_str(":");
@@ -314,7 +317,7 @@ static int handle_team(LW_SRVCHAN *chan, LW_NETMESS *mess,
 	      else
 		{
 		  log_print_str("Team \"");
-		  log_print_str(mess->argv[1]);
+		  log_print_str(mess->argv[2]);
 		  log_print_str("\" on client \"");
 		  log_print_str(chan->ip);
 		  log_print_str(":");
@@ -364,16 +367,18 @@ static int handle_who(LW_SRVCHAN *chan, LW_NETMESS *mess)
 	    {
 	      if (chan->team[i].network)
 		{
-		  sprintf(answer,"%s %d,'%s'",
+		  sprintf(answer,"%s %d,%d,'%s'",
 			  LW_NETMESS_TEXT_NETWORK,
 			  chan->team[i].server_id,
+			  chan->team[i].control_type,
 			  chan->team[i].name);
 		}
 	      else
 		{
-		  sprintf(answer,"%s %d,'%s'",
+		  sprintf(answer,"%s %d,%d,'%s'",
 			  LW_NETMESS_TEXT_LOCAL,
 			  chan->team[i].server_id,
+			  chan->team[i].control_type,
 			  chan->team[i].name);
 		}
 	    }
