@@ -111,7 +111,6 @@ static void reset(LW_SRVCONT *cont)
   cont->sock=-1;
   cont->nb_teams=0;
   cont->nb_chans=0;
-  memset(&(cont->config),0,sizeof(LW_NETCONF));
 }
 
 /*------------------------------------------------------------------*/
@@ -123,6 +122,7 @@ static int distribute_teams(LW_SRVCONT *cont)
   int result=1;
   int i,j,k;
   int i_orig,j_orig;
+  int asm_algorithm;
 
   /*
    * The first step is to attribute a unique number to each
@@ -177,8 +177,9 @@ static int distribute_teams(LW_SRVCONT *cont)
     }
 
   /*
-   * Last step, we copy the team names into all the "nickname" fields.
-   * This will save useless CPU waste later...
+   * Third step, we copy the team names and other parameters in all
+   * the teams structures. This is redundant information but it
+   * will save useless CPU waste later...
    */
   for (i=0;i<cont->nb_chans;++i)
     {
@@ -194,6 +195,8 @@ static int distribute_teams(LW_SRVCONT *cont)
 		{
 		  strcpy(cont->chan[i].team[j].name,
 			 cont->chan[i_orig].team[j_orig].name);
+		  cont->chan[i].team[j].control_type=
+		    cont->chan[i_orig].team[j_orig].control_type;
 		}
 	      else
 		{
@@ -204,6 +207,21 @@ static int distribute_teams(LW_SRVCONT *cont)
 	}
     }
 
+  /*
+   * Last step, we check if the "asm_algorithm" parameter should be
+   * enabled. Indeed, it must be enabled on _all_ computers or on
+   * none of them...
+   */
+  asm_algorithm=1;
+  for (i=0;i<cont->nb_chans;++i)
+    {
+      asm_algorithm=(cont->chan[i].config.asm_algorithm && asm_algorithm);
+    }
+  for (i=0;i<cont->nb_chans;++i)
+    {
+      cont->chan[i].config.asm_algorithm=asm_algorithm;
+    }
+
   return result;
 }
 
@@ -356,7 +374,7 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
 				    &free_teams,
 				    cont->sock,
 				    &(cont->chan[cont->nb_chans].map),
-				    &(cont->config)))
+				    &(cont->chan[cont->nb_chans].config)))
 	    {
 	      cont->nb_teams=nb_teams-free_teams;
 	      ++(cont->nb_chans);
@@ -477,7 +495,7 @@ int lw_srvcont_tell_who(LW_SRVCONT *cont)
 	{
 	  if (!lw_srvchan_tell_who(&(cont->chan[i]),
 				   cont->chan[0].map,
-				   &(cont->config)))
+				   &(cont->chan[0].config)))
 	    {
 	      /*
 	       * There's been an error exchanging data with this team
