@@ -126,7 +126,7 @@ int wave_options (void)
   while (retour==0)
     {
       dp=init_dialog (d,choix);
-      while (update_dialog(dp))
+      while (my_update_dialog(dp))
 	;
       choix=shutdown_dialog (dp);
       //choix=my_do_dialog (d,choix);
